@@ -1083,9 +1083,7 @@ function masort(&$data,$sortby,$rev=0) {
 
 		$code .= 'return $c;';
 
-		$CACHE[$sortby] = function($a, $b) {
-			eval($code);
-		};
+		eval("\$CACHE[\$sortby] = function(\$a, \$b) { $code; };");
 	}
 
 	uasort($data,$CACHE[$sortby]);
